%bcond check 1

Name:           niri
Version:        25.05.1
Release:        %mkrel 1
Summary:        Scrollable-tiling Wayland compositor
# Should be Wayland, but we don't have it
Group:          System/X11

License:        %{shrink:
    GPL-3.0-or-later AND
    Apache-2.0 AND
    BSD-2-Clause AND
    BSD-3-Clause AND
    ISC AND
    MIT AND
    MPL-2.0 AND
    Unicode-3.0 AND
    (0BSD OR MIT OR Apache-2.0) AND
    (Apache-2.0 OR BSL-1.0) AND
    (Apache-2.0 OR MIT) AND
    (Apache-2.0 OR MIT OR Unlicense) AND
    (Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT) AND
    (BSD-2-Clause OR Apache-2.0 OR MIT) AND
    (BSD-3-Clause OR MIT OR Apache-2.0) AND
    (MIT OR Apache-2.0 OR LGPL-2.1-or-later) AND
    (MIT OR Apache-2.0 OR Zlib) AND
    (Unlicense OR MIT)
}
# LICENSE.dependencies contains a full license breakdown

URL:            https://github.com/YaLTeR/niri
Source0:        %{url}/archive/v%{version}/niri-%{version}.tar.gz

# generated by "cargo vendor --versioned-dirs > vendor.toml"
Source1:        niri-%{version}-vendor.tar.xz
Source2:        vendor.toml


BuildRequires:  cargo-rpm-macros
BuildRequires:  clang
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  systemd-rpm-macros

BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libseat)
BuildRequires:  pkgconfig(libspa-0.2)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)

# required for portal support 
Recommends:     gnome-keyring
Recommends:     xdg-desktop-portal-gnome
Recommends:     xdg-desktop-portal-gtk

# required for xwayland support
Recommends:     xwayland-satellite

# applications bound by keyboard shortcuts in default configuration 
Recommends:     alacritty
# Recommends:     fuzzel
Recommends:     swaylock
Recommends:     wireplumber

# applications spawned at startup in default configuration
Recommends:     waybar

%description
A scrollable-tiling Wayland compositor.

%prep
%autosetup -n niri-%{version} -a1 -p1
%cargo_prep -N
# include full configuration for vendored dependencies
cat %{SOURCE2} >> .cargo/config.toml

%build
# set version string without commit information
export NIRI_BUILD_VERSION_STRING="%{version}"
%ifarch %ix86 %arm
%cargo_build -j1
%endif

# generate shell completions
target/rpm/niri completions bash > niri.bash
target/rpm/niri completions fish > niri.fish
target/rpm/niri completions zsh > _niri

# write license summary and breakdown
%{cargo_license_summary}
%{cargo_license} > LICENSE.dependencies

%{cargo_vendor_manifest}
# replace un-parseable git snapshot dependency information
sed 's/\(.*\) (.*#\(.*\))/\1+git\2/' -i cargo-vendor.txt

%install
install -Dpm0755 target/rpm/niri -t %{buildroot}%{_bindir}

install -Dpm0755 resources/niri-session -t %{buildroot}%{_bindir}
install -Dpm0644 resources/niri.desktop -t %{buildroot}%{_datadir}/wayland-sessions
install -Dpm0644 resources/niri-portals.conf -t %{buildroot}%{_datadir}/xdg-desktop-portal
install -Dpm0644 resources/niri.service -t %{buildroot}%{_userunitdir}
install -Dpm0644 resources/niri-shutdown.target -t %{buildroot}%{_userunitdir}

install -Dpm0644 niri.bash -t %{buildroot}%{_datadir}/bash-completion/completions
install -Dpm0644 niri.fish -t %{buildroot}%{_datadir}/fish/vendor_completions.d
install -Dpm0644 _niri -t %{buildroot}%{_datadir}/zsh/site-functions

%if %{with check}
%check
# * skip tests that require a running session
# * limit test parallelism to avoid "too many open files" errors
export RAYON_NUM_THREADS=2
%cargo_test -- --workspace --exclude niri-visual-tests -- --test-threads 2
%endif

%post
%systemd_user_post niri.service

%preun
%systemd_user_preun niri.service

%postun
%systemd_user_postun_with_reload niri.service

%files
%license LICENSE
%license LICENSE.dependencies
%license cargo-vendor.txt

%doc README.md
%doc resources/default-config.kdl
%doc wiki

%{_bindir}/niri
%{_bindir}/niri-session

%dir %{_datadir}/wayland-sessions/
%{_datadir}/wayland-sessions/niri.desktop
%dir %{_datadir}/xdg-desktop-portal/
%{_datadir}/xdg-desktop-portal/niri-portals.conf

%{_userunitdir}/niri.service
%{_userunitdir}/niri-shutdown.target

%{_datadir}/bash-completion/completions/niri.bash
%{_datadir}/fish/vendor_completions.d//niri.fish
%{_datadir}/zsh/site-functions/_niri



%changelog
* Fri Jul 25 2025 papoteur <papoteur> 25.05.1-1.mga10
+ Revision: 2259072
- imported package niri

